from .byteplus_saas_retail_pb2 import (
    WriteDataRequest,
    WriteResponse,
    Device,
    Product,
    PredictRequest,
    PredictResponse,
    AckServerImpressionsRequest,
    AckServerImpressionsResponse,
    FinishWriteDataRequest,
    Date
)